#include <iostream>
#include <vector>
#include <algorithm>

#define ll long long

using namespace std;

template <class T = int>
T next() { T x; cin >> x; return x; }

struct DSU
{
	vector<int> base, range;

	DSU(int n)
	{
		base = vector<int>(n);
		range = vector<int>(n, 1);

		for (int i = 0; i < n; i++) base[i] = i;
	}

	int get_id(int v)
	{
		if (base[v] == v) return base[v];
		base[v] = get_id(base[v]);
		return base[v];
	}

	void merge(int x, int y)
	{
		x = get_id(x); y = get_id(y);
		if (range[x] < range[y]) swap(x, y);

		base[y] = x;
		range[x] += range[y];
	}
};

int main()
{
	int n, m, k;
	cin >> n >> m >> k;

	DSU dsu_friend(n), dsu_way(n), dsu_both(n);

	if (dsu_friend.get_id(0) == dsu_friend.get_id(1))
		dsu_both.merge(0, 1);

	dsu_way.merge(0, 3);
	
	if (dsu_friend.get_id(0) == dsu_friend.get_id(3))
		dsu_both.merge(0, 3);



	for (int i = 0; i < m; i++)
	{
		int u = next() - 1, v = next() - 1;
		dsu_friend.merge(u, v);

		if (dsu_way.get_id(u) == dsu_way.get_id(v)) 
			dsu_both.merge(u, v);
	}

	for (int i = 0; i < k; i++)
	{
		int u = next() - 1, v = next() - 1;
		dsu_way.merge(u, v);

		if (dsu_friend.get_id(u) == dsu_friend.get_id(v))
			dsu_both.merge(u, v);
	}

	int q = next();

	while (q--)
	{
		char c = next<char>();
		
		if (c == 'T')
		{
			int u = next() - 1, v = next() - 1;
			dsu_way.merge(u, v);

			if (dsu_friend.get_id(u) == dsu_friend.get_id(v))
				dsu_both.merge(u, v);
		}

		if (c == 'F')
		{
			int u = next() - 1, v = next() - 1;
			dsu_friend.merge(u, v);

			if (dsu_way.get_id(u) == dsu_way.get_id(v))
				dsu_both.merge(u, v);
		}

		if (c == '?')
		{
			int v = next() - 1;
			cout << dsu_both.range[dsu_both.get_id(v)] - 1 << '\n';
		}
	}
}